<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
